@@ -6,6 +6,7 @@ import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataP
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ReplaceElement;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ReplaceElementProperties;
 import org.gcube.portlets.user.td.expressionwidget.client.properties.ReplaceElementStore;
+import org.gcube.portlets.user.td.expressionwidget.client.type.ReplaceColumnByExpressionType;
 import org.gcube.portlets.user.td.expressionwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.expressionwidget.shared.exception.ReplaceTypeMapException;
 import org.gcube.portlets.user.td.expressionwidget.shared.replace.ReplaceType;
@@ -27,9 +28,7 @@ import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.user.client.rpc.AsyncCallback;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
-import com.sencha.gxt.core.client.dom.ScrollSupport.ScrollMode;
 import com.sencha.gxt.core.client.util.Margins;
-import com.sencha.gxt.core.client.util.ToggleGroup;
 import com.sencha.gxt.data.shared.ListStore;
 import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutData;
 import com.sencha.gxt.widget.core.client.container.HBoxLayoutContainer;
@@ -39,7 +38,6 @@ import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
 import com.sencha.gxt.widget.core.client.event.BeforeShowEvent;
 import com.sencha.gxt.widget.core.client.form.ComboBox;
-import com.sencha.gxt.widget.core.client.form.FieldLabel;
 import com.sencha.gxt.widget.core.client.form.TextField;
 
 /**
@@ -61,29 +59,30 @@ public class ReplaceWidget extends SimpleContainer {
 
 	private ReplaceWidget thisCont;
 
-	protected static final String HEIGHT = "210px";
-	protected static final String WIDTH = "832px";
-	protected static final String COMBO_WIDTH = "170px";
+	private static final String HEIGHT = "210px";
+	private static final String WIDTH = "832px";
+	private static final String COMBO_WIDTH = "170px";
 
-	protected EventBus eventBus;
-	protected TRId trId;
-	protected ArrayList<ColumnData> columns;
+	private EventBus eventBus;
+	private TRId trId;
+	private ArrayList<ColumnData> columns;
 
-	protected FieldLabel matchLabel;
-	protected ToggleGroup groupMatch;
+	// private FieldLabel matchLabel;
+	// private ToggleGroup groupMatch;
 
-	protected VerticalLayoutContainer vert;
+	private VerticalLayoutContainer vert;
 	// protected ColumnData column;
 
-	protected String readableExpression;
+	private String readableExpression;
 	private String itemIdComboConcat;
 	private String itemIdComboLeaf;
 	private String itemIdComboColumns;
 	private String itemIdFirstArg;
 	private String itemIdSecondArg;
 	private String itemIdHoriz;
+	private ReplaceColumnByExpressionType replaceColumnByExpressionType;
 
-	public class ExpressionContainer {
+	protected class ExpressionContainer {
 		private C_Expression expression;
 		private String readableExpression;
 
@@ -114,23 +113,35 @@ public class ReplaceWidget extends SimpleContainer {
 
 	public ReplaceWidget(ColumnData column, EventBus eventBus) {
 		super();
+		replaceColumnByExpressionType = ReplaceColumnByExpressionType.Replace;
 		create(column.getTrId(), WIDTH, HEIGHT, eventBus);
+		retrieveColumns();
 	}
 
 	public ReplaceWidget(ColumnData column, String width, String height,
 			EventBus eventBus) {
 		super();
+		replaceColumnByExpressionType = ReplaceColumnByExpressionType.Replace;
 		create(column.getTrId(), width, height, eventBus);
+		retrieveColumns();
 	}
 
-	public ReplaceWidget(TRId trId, EventBus eventBus) {
-		create(trId, WIDTH, HEIGHT, eventBus);
-	}
-
-	public ReplaceWidget(TRId trId, String width, String height,
+	public ReplaceWidget(ColumnData column, ArrayList<ColumnData> columns,
 			EventBus eventBus) {
 		super();
-		create(trId, width, height, eventBus);
+		replaceColumnByExpressionType = ReplaceColumnByExpressionType.Template;
+		this.columns = columns;
+		create(column.getTrId(), WIDTH, HEIGHT, eventBus);
+		setup();
+	}
+
+	public ReplaceWidget(ColumnData column, ArrayList<ColumnData> columns,
+			String width, String height, EventBus eventBus) {
+		super();
+		replaceColumnByExpressionType = ReplaceColumnByExpressionType.Template;
+		this.columns = columns;
+		create(column.getTrId(), width, height, eventBus);
+		setup();
 	}
 
 	protected void create(TRId trId, String width, String height,
@@ -150,7 +161,6 @@ public class ReplaceWidget extends SimpleContainer {
 
 			}
 		});
-		retrieveColumns();
 
 	}
 
@@ -201,7 +211,7 @@ public class ReplaceWidget extends SimpleContainer {
 		itemIdHoriz = "Horiz" + trId.getId();
 
 		vert = new VerticalLayoutContainer();
-		vert.setScrollMode(ScrollMode.AUTO);
+		//vert.setScrollMode(ScrollMode.AUTO); Set in GXT 3.0.1
 
 		final HBoxLayoutContainer horiz = new HBoxLayoutContainer();
 
@@ -776,7 +786,8 @@ public class ReplaceWidget extends SimpleContainer {
 		return readableExpression;
 	}
 
-	protected ExpressionContainer calcCExpression(int index) throws ReplaceTypeMapException {
+	protected ExpressionContainer calcCExpression(int index)
+			throws ReplaceTypeMapException {
 		ExpressionContainer expressionContainer = null;
 		ExpressionContainer expContainerConcat = null;
 		C_Expression exp = null;
@@ -797,28 +808,57 @@ public class ReplaceWidget extends SimpleContainer {
 		ComboBox<ReplaceElement> comboLeaf = (ComboBox<ReplaceElement>) horiz
 				.getItemByItemId(itemIdComboLeaf);
 		Log.debug("combo Leaf: " + comboLeaf.getCurrentValue());
-		
+
 		@SuppressWarnings("unchecked")
 		ComboBox<ColumnData> comboColumns = (ComboBox<ColumnData>) horiz
 				.getItemByItemId(itemIdComboColumns);
 		Log.debug("combo columns: " + comboColumns.getCurrentValue());
-		ColumnData column=comboColumns.getCurrentValue();
-		
+		ColumnData column = comboColumns.getCurrentValue();
+
 		firstArg = (TextField) horiz.getItemByItemId(itemIdFirstArg);
 		secondArg = (TextField) horiz.getItemByItemId(itemIdSecondArg);
-		Log.debug("[column: "+column+", firstArg: " + firstArg.getCurrentValue() + ", secondArg: "
-				+ secondArg.getCurrentValue()+"]");
+		Log.debug("[column: " + column + ", firstArg: "
+				+ firstArg.getCurrentValue() + ", secondArg: "
+				+ secondArg.getCurrentValue() + "]");
 
 		ReplaceType comboConcatReplaceType = null;
 		ReplaceType comboLeafReplaceType = null;
 
 		if (comboConcat.getCurrentValue() == null) {
 			if (index == vert.getWidgetCount() - 1) {
-				exp = mapReplace.map(column, ReplaceType.Null,
-						firstArg == null ? null : firstArg.getCurrentValue(),
-						secondArg == null ? null : secondArg.getCurrentValue(), false);
+				switch (replaceColumnByExpressionType) {
+				case Replace:
+					exp = mapReplace.map(
+							column,
+							ReplaceType.Null,
+							firstArg == null ? null : firstArg
+									.getCurrentValue(),
+							secondArg == null ? null : secondArg
+									.getCurrentValue(), false);
+					break;
+				case Template:
+					exp = mapReplace.map(
+							column,
+							ReplaceType.Null,
+							firstArg == null ? null : firstArg
+									.getCurrentValue(),
+							secondArg == null ? null : secondArg
+									.getCurrentValue(), true);
+					break;
+				default:
+					exp = mapReplace.map(
+							column,
+							ReplaceType.Null,
+							firstArg == null ? null : firstArg
+									.getCurrentValue(),
+							secondArg == null ? null : secondArg
+									.getCurrentValue(), false);
+					break;
+
+				}
 				readableExp = mapReplace.getReadableExpression();
 				expressionContainer = new ExpressionContainer(exp, readableExp);
+
 			} else {
 				throw new ReplaceTypeMapException("Fill all field!");
 			}
@@ -828,25 +868,73 @@ public class ReplaceWidget extends SimpleContainer {
 			if (comboConcatReplaceType.compareTo(ReplaceType.Concat) == 0) {
 
 				if (comboLeaf.getCurrentValue() == null) {
-					expLeaf = mapReplace.map(
-							column,
-							ReplaceType.Null,
-							firstArg == null ? null : firstArg
-									.getCurrentValue(),
-							secondArg == null ? null : secondArg
-									.getCurrentValue(), false);
+					switch (replaceColumnByExpressionType) {
+					case Replace:
+						expLeaf = mapReplace.map(
+								column,
+								ReplaceType.Null,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), false);
+						break;
+					case Template:
+						expLeaf = mapReplace.map(
+								column,
+								ReplaceType.Null,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), true);
+						break;
+					default:
+						expLeaf = mapReplace.map(
+								column,
+								ReplaceType.Null,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), false);
+						break;
+
+					}
+
 					readableExpLeaf = mapReplace.getReadableExpression();
 
 				} else {
 					comboLeafReplaceType = comboLeaf.getCurrentValue()
 							.getReplaceType();
-					expLeaf = mapReplace.map(
-							column,
-							comboLeafReplaceType,
-							firstArg == null ? null : firstArg
-									.getCurrentValue(),
-							secondArg == null ? null : secondArg
-									.getCurrentValue(), false);
+					switch (replaceColumnByExpressionType) {
+					case Replace:
+						expLeaf = mapReplace.map(
+								column,
+								comboLeafReplaceType,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), false);
+						break;
+					case Template:
+						expLeaf = mapReplace.map(
+								column,
+								comboLeafReplaceType,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), true);
+						break;
+					default:
+						expLeaf = mapReplace.map(
+								column,
+								comboLeafReplaceType,
+								firstArg == null ? null : firstArg
+										.getCurrentValue(),
+								secondArg == null ? null : secondArg
+										.getCurrentValue(), false);
+						break;
+
+					}
+
 					readableExpLeaf = mapReplace.getReadableExpression();
 				}
 
@@ -856,16 +944,45 @@ public class ReplaceWidget extends SimpleContainer {
 					if (expContainerConcat == null) {
 						return null;
 					} else {
-						exp = mapReplace.map(
-								column,
-								comboConcatReplaceType,
-								firstArg == null ? null : firstArg
-										.getCurrentValue(),
-								secondArg == null ? null : secondArg
-										.getCurrentValue(),false, expLeaf,
-								expContainerConcat.getExpression(),
-								readableExpLeaf, expContainerConcat
-										.getReadableExpression());
+						switch (replaceColumnByExpressionType) {
+						case Replace:
+							exp = mapReplace.map(
+									column,
+									comboConcatReplaceType,
+									firstArg == null ? null : firstArg
+											.getCurrentValue(),
+									secondArg == null ? null : secondArg
+											.getCurrentValue(), false, expLeaf,
+									expContainerConcat.getExpression(),
+									readableExpLeaf, expContainerConcat
+											.getReadableExpression());
+							break;
+						case Template:
+							exp = mapReplace.map(
+									column,
+									comboConcatReplaceType,
+									firstArg == null ? null : firstArg
+											.getCurrentValue(),
+									secondArg == null ? null : secondArg
+											.getCurrentValue(), true, expLeaf,
+									expContainerConcat.getExpression(),
+									readableExpLeaf, expContainerConcat
+											.getReadableExpression());
+							break;
+						default:
+							exp = mapReplace.map(
+									column,
+									comboConcatReplaceType,
+									firstArg == null ? null : firstArg
+											.getCurrentValue(),
+									secondArg == null ? null : secondArg
+											.getCurrentValue(), false, expLeaf,
+									expContainerConcat.getExpression(),
+									readableExpLeaf, expContainerConcat
+											.getReadableExpression());
+							break;
+						
+						}
 						readableExp = mapReplace.getReadableExpression();
 						expressionContainer = new ExpressionContainer(exp,
 								readableExp);
@@ -875,9 +992,27 @@ public class ReplaceWidget extends SimpleContainer {
 				}
 
 			} else {
-				exp = mapReplace.map(column, comboConcatReplaceType,
-						firstArg == null ? null : firstArg.getCurrentValue(),
-						secondArg == null ? null : secondArg.getCurrentValue(),false);
+				switch (replaceColumnByExpressionType) {
+				case Replace:
+					exp = mapReplace.map(column, comboConcatReplaceType,
+							firstArg == null ? null : firstArg.getCurrentValue(),
+							secondArg == null ? null : secondArg.getCurrentValue(),
+							false);
+					break;
+				case Template:
+					exp = mapReplace.map(column, comboConcatReplaceType,
+							firstArg == null ? null : firstArg.getCurrentValue(),
+							secondArg == null ? null : secondArg.getCurrentValue(),
+							true);
+					break;
+				default:
+					exp = mapReplace.map(column, comboConcatReplaceType,
+							firstArg == null ? null : firstArg.getCurrentValue(),
+							secondArg == null ? null : secondArg.getCurrentValue(),
+							false);
+					break;
+				
+				}
 				readableExp = mapReplace.getReadableExpression();
 				expressionContainer = new ExpressionContainer(exp, readableExp);
 
